@@ -47,6 +47,7 @@ from google.cloud.dataqna_v1alpha.types import user_feedback
 from .transports.base import DEFAULT_CLIENT_INFO, QuestionServiceTransport
 from .transports.grpc import QuestionServiceGrpcTransport
 from .transports.grpc_asyncio import QuestionServiceGrpcAsyncIOTransport
+from .transports.rest import QuestionServiceRestTransport
 
 
 class QuestionServiceClientMeta(type):
@@ -62,6 +63,7 @@ class QuestionServiceClientMeta(type):
     )  # type: Dict[str, Type[QuestionServiceTransport]]
     _transport_registry["grpc"] = QuestionServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = QuestionServiceGrpcAsyncIOTransport
+    _transport_registry["rest"] = QuestionServiceRestTransport
 
     def get_transport_class(
         cls,
@@ -394,6 +396,9 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
             transport (Union[str, QuestionServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
+                NOTE: "rest" transport functionality is currently in a
+                beta state (preview). We welcome your feedback via an
+                issue in this library's source repository.
             client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
@@ -487,6 +492,13 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataqna_v1alpha
 
             def sample_get_question():
@@ -586,6 +598,13 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataqna_v1alpha
 
             def sample_create_question():
@@ -594,7 +613,7 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
 
                 # Initialize request argument(s)
                 question = dataqna_v1alpha.Question()
-                question.scopes = ['scopes_value_1', 'scopes_value_2']
+                question.scopes = ['scopes_value1', 'scopes_value2']
                 question.query = "query_value"
 
                 request = dataqna_v1alpha.CreateQuestionRequest(
@@ -698,6 +717,13 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataqna_v1alpha
 
             def sample_execute_question():
@@ -806,6 +832,13 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataqna_v1alpha
 
             def sample_get_user_feedback():
@@ -902,6 +935,13 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import dataqna_v1alpha
 
             def sample_update_user_feedback():
